summaryrefslogtreecommitdiff
path: root/MdePkg/Include/Protocol/Mtftp4.h
diff options
context:
space:
mode:
authorlzeng14 <lzeng14@6f19259b-4bc3-4df7-8a09-765794883524>2011-06-08 05:53:18 +0000
committerlzeng14 <lzeng14@6f19259b-4bc3-4df7-8a09-765794883524>2011-06-08 05:53:18 +0000
commit4f0779023cb4f633425a6fa8df747326336f2077 (patch)
treeb4b886d425bb25ddd135777f46264f493b9a841e /MdePkg/Include/Protocol/Mtftp4.h
parent8052c4a2b9e0c3575e912e5867cd0d7c2669c925 (diff)
downloadedk2-4f0779023cb4f633425a6fa8df747326336f2077.zip
edk2-4f0779023cb4f633425a6fa8df747326336f2077.tar.gz
edk2-4f0779023cb4f633425a6fa8df747326336f2077.tar.bz2
String Reference Cleanup.
Signed-off-by: lzeng14 Reviewed-by: lgao4 git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@11762 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdePkg/Include/Protocol/Mtftp4.h')
-rw-r--r--MdePkg/Include/Protocol/Mtftp4.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/MdePkg/Include/Protocol/Mtftp4.h b/MdePkg/Include/Protocol/Mtftp4.h
index 031ef18..1afac6c 100644
--- a/MdePkg/Include/Protocol/Mtftp4.h
+++ b/MdePkg/Include/Protocol/Mtftp4.h
@@ -1,7 +1,7 @@
/** @file
EFI Multicast Trivial File Tranfer Protocol Definition
-Copyright (c) 2006 - 2010, Intel Corporation. All rights reserved.<BR>
+Copyright (c) 2006 - 2011, Intel Corporation. All rights reserved.<BR>
This program and the accompanying materials are licensed and made available under
the terms and conditions of the BSD License that accompanies this distribution.
The full text of the license may be found at
@@ -313,8 +313,8 @@ EFI_STATUS
@param OverrideData Data that is used to override the existing parameters. If NULL,
the default parameters that were set in the
EFI_MTFTP4_PROTOCOL.Configure() function are used.
- @param Filename The pointer to ASCIIZ file name string.
- @param ModeStr The pointer to ASCIIZ mode string. If NULL, "octet" will be used.
+ @param Filename The pointer to null-terminated ASCII file name string.
+ @param ModeStr The pointer to null-terminated ASCII mode string. If NULL, "octet" will be used.
@param OptionCount Number of option/value string pairs in OptionList.
@param OptionList The pointer to array of option/value string pairs. Ignored if
OptionCount is zero.
@@ -542,11 +542,11 @@ struct _EFI_MTFTP4_TOKEN {
///
EFI_MTFTP4_OVERRIDE_DATA *OverrideData;
///
/// The pointer to the ASCIIZ file name string.
///
UINT8 *Filename;
///
/// The pointer to the ASCIIZ mode string. If NULL, "octet" is used.
///
UINT8 *ModeStr;
///
@@ -542,11 +542,11 @@ struct _EFI_MTFTP4_TOKEN {
EFI_MTFTP4_OVERRIDE_DATA *OverrideData;
///
- /// The pointer to the ASCIIZ file name string.
+ /// The pointer to the null-terminated ASCII file name string.
///
UINT8 *Filename;
@@ -542,11 +542,11 @@ struct _EFI_MTFTP4_TOKEN {
UINT8 *Filename;
///
- /// The pointer to the ASCIIZ mode string. If NULL, "octet" is used.
+ /// The pointer to the null-terminated ASCII mode string. If NULL, "octet" is used.
///
UINT8 *ModeStr;